/**
 * An implementation of Set backed by Dict
 * Values can be anything, with deep-equality comparison
 * API compatible with native Set
 * Note: Unlike Set, order of insertion is not retained for iteration methods
 *
 * @public
 * @category Structures
 */
export declare class HashSet<V> implements Iterable<V> {
    static from<V>(): HashSet<V>;
    static from<V>(array: readonly V[]): HashSet<V>;
    static from<V>(set: Set<V>): HashSet<V>;
    private dict;
    constructor();
    constructor(values: readonly V[] | null);
    constructor(iterable: Iterable<V> | null);
    add(val: V): HashSet<V>;
    clear(): void;
    delete(val: V): boolean;
    difference(other: HashSet<V>): HashSet<V>;
    entries(): IteratorObject<V[], undefined, unknown>;
    forEach(fn: (val: V) => void): void;
    has(val: V): boolean;
    intersection(other: HashSet<V>): HashSet<V>;
    isDisjointFrom(other: HashSet<V>): boolean;
    isSubsetOf(other: HashSet<V>): boolean;
    isSupersetOf(other: HashSet<V>): boolean;
    keys(): IteratorObject<V, undefined, unknown>;
    symmetricDifference(other: HashSet<V>): HashSet<V>;
    union(other: HashSet<V>): HashSet<V>;
    values(): IteratorObject<V, undefined, unknown>;
    [Symbol.iterator](): IteratorObject<V, undefined, unknown>;
    get size(): number;
    hashCode(): number;
    clone(): HashSet<V>;
    equals(other: HashSet<V>): boolean;
    map<U>(callbackFn: (val: V) => U): HashSet<U>;
    filter<S extends V>(predicate: (value: V) => value is S): HashSet<S>;
    find<S extends V>(predicate: (value: V) => value is S): S | undefined;
    reduce(callbackFn: (accumulator: V, value: V) => V): V;
    reduce(callbackFn: (accumulator: V, value: V) => V, initialValue: V): V;
    reduce<U>(callbackFn: (accumulator: U, value: V) => U, initialValue: U): U;
    some(predicate: (value: V) => boolean): boolean;
    every(predicate: (value: V) => boolean): boolean;
}
